@@ -1,17 +1,35 @@
-require "ruby_prof.so"
+# encoding: utf-8
 
-require "ruby-prof/method_info"
-require "ruby-prof/call_info"
-require "ruby-prof/aggregate_call_info"
-require "ruby-prof/flat_printer"
-require "ruby-prof/graph_printer"
-require "ruby-prof/graph_html_printer"
-require "ruby-prof/call_tree_printer"
+# Load the C-based binding.
+begin
+  RUBY_VERSION =~ /(\d+.\d+)/
+  require "#{$1}/ruby_prof"
+rescue LoadError
+  require "ruby_prof"
+end
 
-require "ruby-prof/test"
+require 'ruby-prof/aggregate_call_info'
+require 'ruby-prof/call_info'
+require 'ruby-prof/call_info_visitor'
+require 'ruby-prof/compatibility'
+require 'ruby-prof/method_info'
+require 'ruby-prof/profile'
+require 'ruby-prof/rack'
+require 'ruby-prof/thread'
+
+require 'ruby-prof/printers/abstract_printer'
+require 'ruby-prof/printers/call_info_printer'
+require 'ruby-prof/printers/call_stack_printer'
+require 'ruby-prof/printers/call_tree_printer'
+require 'ruby-prof/printers/dot_printer'
+require 'ruby-prof/printers/flat_printer'
+require 'ruby-prof/printers/flat_printer_with_line_numbers'
+require 'ruby-prof/printers/graph_html_printer'
+require 'ruby-prof/printers/graph_printer'
+require 'ruby-prof/printers/multi_printer'
 
 module RubyProf
-  # See if the user specified the clock mode via 
+  # Checks if the user specified the clock mode via
   # the RUBY_PROF_MEASURE_MODE environment variable
   def self.figure_measure_mode
     case ENV["RUBY_PROF_MEASURE_MODE"]
@@ -40,9 +58,10 @@ module RubyProf
     when "memory"
       RubyProf.measure_mode = RubyProf::MEMORY
     else
+      # the default...
       RubyProf.measure_mode = RubyProf::PROCESS_TIME
     end
   end
 end
 
-RubyProf::figure_measure_mode
+RubyProf::figure_measure_mode
\ No newline at end of file
