@@ -1,6 +1,9 @@
+# encoding: utf-8
+
 module RubyProf
   class AggregateCallInfo
     attr_reader :call_infos
+
     def initialize(call_infos)
       if call_infos.length == 0
         raise(ArgumentError, "Must specify at least one call info.")
@@ -27,19 +30,19 @@ module RubyProf
     end
 
     def total_time
-      aggregate(:total_time)
+      aggregate_without_recursion(:total_time)
     end
 
     def self_time
-      aggregate(:self_time)
+      aggregate_without_recursion(:self_time)
     end
 
     def wait_time
-      aggregate(:wait_time)
+      aggregate_without_recursion(:wait_time)
     end
 
     def children_time
-      aggregate(:children_time)
+      aggregate_without_recursion(:children_time)
     end
 
     def called
@@ -47,7 +50,7 @@ module RubyProf
     end
 
     def to_s
-      "#{call_infos.first.full_name}"
+      "#{call_infos.first.target.full_name}"
     end
 
     private
@@ -58,5 +61,12 @@ module RubyProf
         sum
       end
     end
+
+    def aggregate_without_recursion(method_name)
+      self.call_infos.inject(0) do |sum, call_info|
+        sum += call_info.send(method_name) unless call_info.recursive
+        sum
+      end
+    end
   end
-end
\ No newline at end of file
+end
